#ifndef REMOVE_SOURCE_UNLINK_H
#define REMOVE_SOURCE_UNLINK_H

/*******************************************************************************
*******************************************************************************/
#define REMOVE_SOURCE_UNLINK \
{\
	if(cpinfo->src_para == DEFAULT)\
	{\
		errno = 0;\
		if(unlink(cpinfo->src) == -1)\
		{\
			if(errno != ENOENT)\
			{\
				print_error("unlink", cpinfo->src, __FILE__, __LINE__, cpdd);\
			}\
		}\
		else \
		{\
			cpinfo->src_para = REMOVE;\
		}\
	}\
}

#endif
